Project hosting with Launchpad
==============================

`Launchpad`_ hosts the Cinder project. The Cinder project homepage on Launchpad
is https://launchpad.net/cinder.

Launchpad credentials
---------------------

Creating a login on Launchpad is important even if you don't use the Launchpad
site itself, since Launchpad credentials are used for logging in on several
OpenStack-related sites. These sites include:

 * `Wiki`_
 * Gerrit (see :doc:`gerrit`)
 * Zuul (see :doc:`zuul`)

Mailing list
------------

The mailing list email is ``openstack-discuss@lists.openstack.org``.
This is a common mailing list across the OpenStack projects. To
participate in the mailing list:

#. Subscribe to the list at
   https://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-discuss

The mailing list archives are at
https://lists.openstack.org/pipermail/openstack-discuss/.


Bug tracking
------------

Report Cinder bugs at https://bugs.launchpad.net/cinder

Feature requests (Blueprints)
-----------------------------

Cinder uses Launchpad Blueprints to track feature requests. Blueprints are at
https://blueprints.launchpad.net/cinder.

Technical support (Answers)
---------------------------

Cinder no longer uses Launchpad Answers to track Cinder technical support
questions.

Note that `Ask OpenStack`_ (which is not hosted on Launchpad) can
be used for technical support requests.

.. _Launchpad: https://launchpad.net
.. _Wiki: https://wiki.openstack.org/wiki/Main_Page
.. _Cinder Team: https://launchpad.net/~cinder
.. _OpenStack Team: https://launchpad.net/~openstack
.. _Ask OpenStack: https://ask.openstack.org
